@@ -9,10 +9,6 @@
 #' that one may add additional information layer by layer to the figure as
 #' geoms as necessary.
 #'
-#' @import ggplot2
-#' @importFrom ggplot2 ggproto
-#' @inheritParams ggplot2::layer
-#'
 #' @seealso \code{\link{lolli_plot}} for a non-geom based lolliplot function.
 #'
 #' @section Aesthetics:
@@ -38,6 +34,29 @@
 #' discrete. ggplot2 will attempt to do this automatically.
 #' }
 #'
+#' @param mapping Set of aesthetic mappings created by \code{aes()} or \code{aes_()}. If
+#' specified and inherit.aes = TRUE (the default), it is combined with the
+#' default mapping at the top level of the plot. You must supply mapping if
+#' there is no plot mapping.
+#' @param data The data to be displayed in this layer. There are three options:
+#'
+#' If NULL, the default, the data is inherited from the plot data as specified
+#' in the call to \code{ggplot()}.
+#'
+#' A data.frame, or other object, will override the plot data. All objects will
+#' be fortified to produce a data frame. See \code{fortify()} for which variables will
+#' be created.
+#'
+#' A function will be called with a single argument, the plot data. The return
+#' value must be a \code{data.frame}, and will be used as the layer data.
+#' @param show.legend Logical. Should this layer be included in the legends? \code{NA},
+#' the default, includes if any aesthetics are mapped. \code{FALSE} never includes, and
+#' \code{TRUE} always includes. It can also be a named logical vector to finely select
+#' the aesthetics to display.
+#' @param inherit.aes If \code{FALSE}, overrides the default aesthetics, rather
+#' than combining with them. This is most useful for helper functions that define
+#' both data and aesthetics and shouldn't inherit behaviour from the default plot
+#' specification, e.g. \code{borders()}.
 #' @param na.rm If \code{FALSE} (the default), removes missing values with
 #'    a warning. If \code{TRUE} silently removes missing values.
 #' @param ... other arguments passed on to \code{\link{layer}}. These are
@@ -52,9 +71,9 @@
 #' @export
 #'
 #' @examples
-#' t_dat <- make_whole(sst_NW_Atl)
+#' ts_dat <- make_whole(sst_NW_Atl)
 #' # with defaults:
-#' res <- detect(t_dat, climatology_start = 1983, climatology_end = 2012)
+#' res <- detect(ts_dat, climatology_start = 1983, climatology_end = 2012)
 #' mhw <- res$event
 #'
 #' \dontrun{
@@ -97,10 +116,10 @@ geom_lolli <- function(mapping = NULL, data = NULL,
 
 GeomLolli <- ggplot2::ggproto("GeomLolli", ggplot2::Geom,
                               required_aes = c("x", "y"),
-                              default_aes = aes(shape = 19, colour = "grey35", size = 1, fill = NA,
+                              default_aes = ggplot2::aes(shape = 19, colour = "grey35", size = 1, fill = NA,
                                                 alpha = NA, stroke = 1, colour.n = "black"),
 
-                              draw_key = draw_key_point,
+                              draw_key = ggplot2::draw_key_point,
 
                               draw_group = function(data, panel_scales, coord, n) {
                                 data$xend = data$x
